# $Id: mt-bmquote.pl 731 2007-08-07 22:12:36Z endo $

package MT::Plugin::BMQuote;

use strict;
use MT::Plugin;
@MT::Plugin::BMQuote::ISA = qw(MT::Plugin);

my $PLUGIN_NAME = 'BMQuote';
my $VERSION = '0.61';

my $HTML_TYPE = 1;

use MT;
my $plugin = new MT::Plugin::BMQuote({
    name => $PLUGIN_NAME,
    version => $VERSION,
    description => "This plugin allows you to change the quotation format of QuickPost.",
    doc_link => 'http://labs.m-logic.jp/plugins/mt-bmquote/docs/mt-bmquote.html',
    author_name => 'M-Logic, Inc.',
    author_link => 'http://labs.m-logic.jp/',
});

MT->add_plugin($plugin);
MT->add_callback('MT::App::CMS::AppTemplateParam.bm_entry', 9, $plugin, \&transformer);
MT->add_callback('MT::App::CMS::template_param.edit_entry', 9, $plugin, \&mt4_transformer);

sub instance { $plugin; }

sub transformer {
    my ($eh, $app, $param, $tmpl) = @_;
    my $q = $app->param;
    my $html = $param->{text};

    my $old = q{<a title="(.*)" href="(.*)">(.*)</a>\n\n(.*)$};
    $html =~ m!$old!s;

    my $new;
    if ($HTML_TYPE == 2) {
        $new = _make_html_exp($1, $2, $4);
    } else {
        $new = _make_html_std($1, $2, $4);
    }

    $param->{text} =~ s!$old!$new!gs;

    return 1;
}

sub mt4_transformer {
    my ($eh, $app, $param, $tmpl) = @_;
    my $q = $app->param;
    return 1 unless $q->param('qp');
    my $html = $param->{text};
    my $title = $param->{title};
    my $old = q{^(.*)<br/><br/>(.*)$};
    $html =~ m!$old!s;
    my $new;
    if($HTML_TYPE == 2) {
        $new = _make_html_exp($title, $1, $2);
    }
    else {
        $new = _make_html_std($title, $1, $2);
    }
    $param->{text} =~ s!$old!$new!gs;
    1;
}

sub _make_html_std {
    my ($title, $url, $sel_text) = @_;
    my $html = <<"HTML";
<blockquote><div class="quotetitle"><a title="$title" href="$url" target="_blank">$title</a></div>\n\n$sel_text\n\n</blockquote>
HTML

    $html;
}

sub _make_html_exp {
    my ($title, $url, $sel_text) = @_;
    # $ENV{'TZ'} = "JST-9";
    my $times = time();
    my ($sec,$min,$hour,$mday,$month,$year,$wday,$stime) = localtime($times);
    my $date = sprintf("%04d\/%02d\/%02d\ %02d\:%02d\:%02d", $year+1900, $month+1, $mday, $hour, $min, $sec);

    my $html = <<"HTML";
<blockquote cite="$url" title="Source:$title | Accessed Date:$date" class="blockquote">
<p>$sel_text</p>
</blockquote>
<a class="cite">
[ <cite><a href="$url" title="$title" target="_blank">$title</a></cite> ]
</a>
HTML

    $html;
}


1;
